pub enum Response {
Ok {
result: PlaceResult,
},
ZeroResults,
InvalidRequest,
OverQueryLimit,
RequestDenied {
error_message: String,
},
UnknownError,
}Expand description
https://developers.google.com/maps/documentation/places/web-service/details#PlacesDetailsStatus
Variants
Ok
OK indicating the API request was successful.
Includes PlaceResult in result.
Fields

result: PlaceResultZeroResults
ZERO_RESULTS indicating that the referenced location, place_id, was valid but no longer refers to a valid result.
This may occur if the establishment is no longer in business.
InvalidRequest
INVALID_REQUEST indicating the API request was malformed
OverQueryLimit
OVER_QUERY_LIMIT indicating any of the following:
- You have exceeded the QPS limits.
- Billing has not been enabled on your account.
- The monthly $200 credit, or a self-imposed usage cap, has been exceeded.
- The provided method of payment is no longer valid (for example, a credit card has expired).
RequestDenied
REQUEST_DENIED indicating that your request was denied, generally because:
- The request is missing an API key.
- The
keyparameter is invalid.
UnknownError
UNKNOWN_ERROR indicating an unknown error